@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Rinci;
 
-our $DATE = '2015-04-14'; # DATE
-our $VERSION = '0.40'; # VERSION
+our $DATE = '2015-07-04'; # DATE
+our $VERSION = '0.41'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -382,8 +382,10 @@ sub _process_script {
             my $opts = $clidocdata{''}{opts};
             # find all the categories
             my %options_by_cat; # val=[options...]
-            for (keys %$opts) {
-                push @{ $options_by_cat{$opts->{$_}{category}} }, $_;
+            for my $optkey (keys %$opts) {
+                for my $cat (@{ $opts->{$optkey}{categories} }) {
+                    push @{ $options_by_cat{$cat} }, $optkey;
+                }
             }
             my $cats_spec = $clidocdata{''}{option_categories};
             for my $cat (sort {
@@ -594,7 +596,7 @@ Pod::Weaver::Plugin::Rinci - Insert stuffs to POD from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.40 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-04-14.
+This document describes version 0.41 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-07-04.
 
 =head1 SYNOPSIS
 
